@@ -2,6 +2,6 @@ from tileserver.leaflet import (  # noqa
     get_leaflet_tile_layer,
 )
 from tileserver.report import Report  # noqa
-from tileserver.run import TileServer  # noqa
+from tileserver.server import TileServer  # noqa
 from tileserver.utilities import get_cache_dir  # noqa
 from tileserver._version import __version__  # noqa
